@@ -19,6 +19,7 @@ from multipart.multipart import parse_options_header
 
 # ME
 from meutils.pipe import *
+from meutils.str_utils import json_loads
 
 
 # app_ = FastAPI(title='AppZoo')  # todo: 全局变量
@@ -203,8 +204,9 @@ class App(object):
             input = request.query_params._dict
             body = await request.body()  # get 一般为空
 
-            if body:
-                input.update(json.loads(body))  # 避免重复 key
+            if body:  # 避免重复 key
+                # input.update(json.loads(body))
+                input.update(json_loads(body))
 
             # input4str 方便 cache
             if str(func.__annotations__).__contains__('str'):
@@ -239,21 +241,21 @@ class App(object):
         return output
 
     @staticmethod
-    def _try_func_plus(input, func, result_key='data', **kwargs):
+    def _try_func_plus(input, func, **kwargs):
 
-        output = OrderedDict()
-        output['error_code'] = 0
-        output['error_msg'] = "SUCCESS"
+        output = OrderedDict(code=0, msg="SUCCESS", **kwargs)
 
         try:
-            output[result_key] = func(input)
+            output['data'] = func(input)
 
         except Exception as error:
-            output['error_code'] = 1  # 通用错误
-            output['error_msg'] = traceback.format_exc().strip()  # debug状态获取详细信息
+            output['code'] = 1  # 通用错误
+            output['msg'] = traceback.format_exc().strip()  # debug状态获取详细信息
 
-        finally:
-            output.update(kwargs)
+            logger.error(output['msg'])
+
+        # finally:
+        #     output.update(kwargs)
 
         return output
 
