@@ -9,5 +9,5 @@
 # @Description  : 
 
 
-from .App import App, app_
+from .App import App
 from .RpcApp import RpcApp
