@@ -54,9 +54,18 @@ def easy_run(app_dir: str, port=8051, access_log: bool = True):
     from appzoo import App
 
     app = App()
-    app.add_apps(app_dir)
+    app.add_apps(app_dir, code=200)
     app.run(port=port, access_log=access_log)
 
 
+# 网盘
+@cli.command()
+def easy_run(port=9955, home=None):
+    cmd = f"pyhton3 -m http.server {port}"
+    if home:
+        cmd = f"cd {home} && " + cmd
+    os.system(cmd)
+
+
 if __name__ == '__main__':
     cli()
